@@ -1,6 +1,7 @@
 """Main module."""
 
 import pandas as pd
+import numpy as np
 import pickle
 import os
 import json
@@ -13,7 +14,7 @@ try:
     from igel.configs import configs
     from igel.data import models_dict, metrics_dict
     from igel.preprocessing import update_dataset_props
-    from igel.preprocessing import handle_missing_values, encode, normalize
+    from igel.preprocessing import handle_missing_values, encode, normalize, read_data_to_df
     from igel.hyperparams import hyperparameter_search
 except ImportError:
     from utils import read_yaml, create_yaml, extract_params, _reshape, read_json
@@ -21,7 +22,7 @@ except ImportError:
     from configs import configs
     from data import models_dict, metrics_dict
     from preprocessing import update_dataset_props
-    from preprocessing import handle_missing_values, encode, normalize
+    from preprocessing import handle_missing_values, encode, normalize, read_data_to_df
     from hyperparams import hyperparameter_search
 
 from sklearn.model_selection import train_test_split, cross_validate
@@ -78,6 +79,16 @@ class Igel(object):
                         f"model_props: {self.model_props} \n "
                         f"target: {self.target} \n")
 
+            # handle random numbers generation
+            random_num_options = self.dataset_props.get('random_numbers', None)
+            if random_num_options:
+                generate_reproducible = random_num_options.get('generate_reproducible', None)
+                if generate_reproducible:
+                    logger.info("You provided the generate reproducible results option.")
+                    seed = random_num_options.get('seed', 42)
+                    np.random.seed(seed)
+                    logger.info(f"Setting a seed = {seed} to generate same random numbers on each experiment..")
+
         # if entered command is evaluate or predict, then the pre-fitted model needs to be loaded and used
         else:
             self.model_path = cli_args.get('model_path', self.default_model_path)
@@ -189,9 +200,8 @@ class Igel(object):
             assert len(self.target) > 0, "please provide at least a target to predict"
 
         try:
-            read_data_options = self.dataset_props.get('read_data_options', None)
-            dataset = pd.read_csv(self.data_path) if not read_data_options else pd.read_csv(self.data_path,
-                                                                                            **read_data_options)
+            read_data_options = self.dataset_props.get('read_data_options', {})
+            dataset = read_data_to_df(data_path=self.data_path, **read_data_options)
             logger.info(f"dataset shape: {dataset.shape}")
             attributes = list(dataset.columns)
             logger.info(f"dataset attributes: {attributes}")
